#profile {
    float: right;
    margin-top: 100px;
    margin-left: 3%;
    width: 16%;
    min-width: 200px;
}

#tab-content-levels > div:nth-child(odd) {
    padding: 10px;
}

#tab-content-levels > div:nth-child(even) {
    padding: 10px;
    background: rgba(187, 234, 249, 0.5);
}

#profile img {
    width: 140px;
    height: 140px;
    margin-bottom: 50px;
    margin-left: 5%;
}

#choice > label {
    background-color: white;
    border: none;
}

#wrapper {
    float: left;
    width: 60%;
    margin-top: 30px;
    margin-left: 3%;
    min-width: 500px;
}

#choice {
    float: left;
}

#wrapper > ul {
    width: 100%;
}

.tabs > li > label {
    display:inline-block;
    width: 100%;

}

.tabs li {
    width: 33.33333%;
}

.tab-content {
    padding: 40px;
    width: 100%;
}

.shareButton {
    float: right;
}
